<?php
/**
 * Plugin Name: tag-pinyin-converter
 * Plugin URI: https://www.system.cab/soft/110818.html
 * Description: 自动将文章标签的别名(slug)转换为拼音或首字母缩写
 * Version: 1.0.4
 * Author: Evil
 * Author URI: https://www.system.cab/
 * License: GPL-2.0-or-later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: https://www.system.cab/soft/110818.html
 */

defined('ABSPATH') || exit;

// 检查PHP版本
register_activation_hook(__FILE__, function() {
    if (version_compare(PHP_VERSION, '7.0.0', '<')) {
        deactivate_plugins(plugin_basename(__FILE__));
        wp_die(__('本插件需要PHP 7.0或更高版本', 'tag-pinyin-converter'));
    }
});

// 加载拼音库
try {
    if (file_exists(__DIR__ . '/vendor/autoload.php')) {
        require_once __DIR__ . '/vendor/autoload.php';
    } elseif (file_exists(__DIR__ . '/Pinyin.php')) {
        require_once __DIR__ . '/Pinyin.php';
    } else {
        throw new Exception(__('缺少拼音库文件', 'tag-pinyin-converter'));
    }
    
    if (!class_exists('Overtrue\Pinyin\Pinyin')) {
        throw new Exception(__('拼音库加载失败', 'tag-pinyin-converter'));
    }
} catch (Exception $e) {
    add_action('admin_notices', function() use ($e) {
        echo '<div class="error notice"><p>'.esc_html__('标签拼音转换器错误: ', 'tag-pinyin-converter').esc_html($e->getMessage()).'</p></div>';
    });
    return;
}

class Tag_Slug_Pinyin_Converter {
    
    private $options;
    private $pinyin;
    
    public function __construct() {
        $this->options = get_option('tag_slug_pinyin_options', $this->get_default_options());
        $this->pinyin = new Overtrue\Pinyin\Pinyin();
        
        add_action('admin_menu', [$this, 'add_admin_menu']);
        add_action('admin_init', [$this, 'settings_init']);
        
        add_action('created_post_tag', [$this, 'convert_tag_slug'], 10, 2);
        add_action('edited_post_tag', [$this, 'convert_tag_slug'], 10, 2);
        add_action('save_post', [$this, 'update_all_tag_slugs'], 99);
    }
    
    private function get_default_options() {
        return [
            'conversion_type' => 'pinyin',
            'separator' => '-',
            'keep_original' => 0
        ];
    }
    
    // 添加设置选项安全验证
    private function sanitize_options($input) {
        $output = $this->get_default_options();
        
        if (isset($input['conversion_type'])) {
            $output['conversion_type'] = in_array($input['conversion_type'], ['pinyin', 'abbr']) ? 
                $input['conversion_type'] : 'pinyin';
        }
        
        if (isset($input['separator'])) {
            $output['separator'] = sanitize_text_field($input['separator']);
        }
        
        if (isset($input['keep_original'])) {
            $output['keep_original'] = absint($input['keep_original']);
        }
        
        return $output;
    }
    
    public function add_admin_menu() {
        add_options_page(
            __('标签拼音转换设置', 'tag-pinyin-converter'),
            __('标签拼音转换', 'tag-pinyin-converter'),
            'manage_options',
            'tag_slug_pinyin',
            [$this, 'options_page']
        );
    }
    
    public function settings_init() {
        register_setting(
            'tag_slug_pinyin',
            'tag_slug_pinyin_options',
            ['sanitize_callback' => [$this, 'sanitize_options']]
        );
        
        // ... 其他设置代码保持不变 ...
    }
    
    // ... 其他方法保持不变 ...
}

new Tag_Slug_Pinyin_Converter();